
## CATO-CLI - mutation.groups:
[Click here](https://api.catonetworks.com/documentation/#mutation-groups) for documentation on this operation.

### Usage for mutation.groups:

`catocli mutation groups -h`
